@@ -1,25 +1,6 @@
 /*
- *
- *  JBoss, Home of Professional Open Source.
- *  Copyright 2012, Red Hat, Inc., and individual contributors
- *  as indicated by the @author tags. See the copyright.txt file in the
- *  distribution for a full listing of individual contributors.
- *
- *  This is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU Lesser General Public License as
- *  published by the Free Software Foundation; either version 2.1 of
- *  the License, or (at your option) any later version.
- *
- *  This software is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this software; if not, write to the Free
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- *  02110-1301 USA, or see the FSF site: http://www.fsf.org.
- * /
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 
 package org.jboss.as.connector.subsystems.datasources;
@@ -45,10 +26,11 @@ public class DataSourcesSubsystemRootDefinition extends SimpleResourceDefinition
 
 
     private DataSourcesSubsystemRootDefinition(final boolean registerRuntimeOnly, final boolean deployed) {
-        super(PATH_SUBSYSTEM,
-                DataSourcesExtension.getResourceDescriptionResolver(),
-                deployed ? null : DataSourcesSubsystemAdd.INSTANCE,
-                deployed ? null : ReloadRequiredRemoveStepHandler.INSTANCE);
+        super(new Parameters(PATH_SUBSYSTEM, DataSourcesExtension.getResourceDescriptionResolver())
+                .setAddHandler(deployed ? null : DataSourcesSubsystemAdd.INSTANCE)
+                .setRemoveHandler(deployed ? null : ReloadRequiredRemoveStepHandler.INSTANCE)
+                .setFeature(!deployed)
+                .setRuntime(deployed));
         this.registerRuntimeOnly = registerRuntimeOnly;
         this.deployed = deployed;
     }
@@ -82,7 +64,7 @@ public class DataSourcesSubsystemRootDefinition extends SimpleResourceDefinition
     @Override
     public void registerChildren(ManagementResourceRegistration resourceRegistration) {
         if (! deployed )
-            resourceRegistration.registerSubModel(JdbcDriverDefinition.INSTANCE);
+            resourceRegistration.registerSubModel(new JdbcDriverDefinition());
         resourceRegistration.registerSubModel(DataSourceDefinition.createInstance(registerRuntimeOnly, deployed));
         resourceRegistration.registerSubModel(XaDataSourceDefinition.createInstance(registerRuntimeOnly, deployed));
     }
