@@ -1,23 +1,6 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2011, Red Hat, Inc., and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 
 package org.jboss.as.jpa.service;
@@ -26,15 +9,16 @@ import java.security.AccessControlContext;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
 import java.util.Collections;
+import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.RejectedExecutionException;
 
-import javax.enterprise.inject.spi.BeanManager;
-import javax.persistence.EntityManagerFactory;
-import javax.persistence.spi.PersistenceProvider;
+import jakarta.enterprise.inject.spi.BeanManager;
+import jakarta.persistence.EntityManagerFactory;
+import jakarta.persistence.spi.PersistenceProvider;
 import javax.sql.DataSource;
-import javax.validation.ValidatorFactory;
+import jakarta.validation.ValidatorFactory;
 
 import org.jboss.as.jpa.beanmanager.BeanManagerAfterDeploymentValidation;
 import org.jboss.as.jpa.beanmanager.ProxyBeanManager;
@@ -53,6 +37,7 @@ import org.jboss.msc.service.StopContext;
 import org.jboss.msc.value.InjectedValue;
 import org.jipijapa.plugin.spi.EntityManagerFactoryBuilder;
 import org.jipijapa.plugin.spi.PersistenceProviderAdaptor;
+import org.jipijapa.plugin.spi.PersistenceProviderIntegratorAdaptor;
 import org.jipijapa.plugin.spi.PersistenceUnitMetadata;
 import org.wildfly.security.manager.action.GetAccessControlContextAction;
 import org.wildfly.security.manager.WildFlySecurityManager;
@@ -66,19 +51,22 @@ import static org.jboss.as.jpa.messages.JpaLogger.ROOT_LOGGER;
  * The persistence unit scoped
  *
  * @author Scott Marlow
+ * @author <a href="mailto:ropalka@redhat.com">Richard Opalka</a>
  */
 public class PersistenceUnitServiceImpl implements Service<PersistenceUnitService>, PersistenceUnitService {
-    private final InjectedValue<Map> properties = new InjectedValue<Map>();
     private final InjectedValue<DataSource> jtaDataSource = new InjectedValue<DataSource>();
     private final InjectedValue<DataSource> nonJtaDataSource = new InjectedValue<DataSource>();
     private final InjectedValue<ExecutorService> executorInjector = new InjectedValue<ExecutorService>();
     private final InjectedValue<BeanManager> beanManagerInjector = new InjectedValue<>();
     private final InjectedValue<PhaseOnePersistenceUnitServiceImpl> phaseOnePersistenceUnitServiceInjectedValue = new InjectedValue<>();
 
-    private static final String CDI_BEAN_MANAGER = "javax.persistence.bean.manager";
-    private static final String VALIDATOR_FACTORY = "javax.persistence.validation.factory";
+    private static final String EE_NAMESPACE = BeanManager.class.getName().startsWith("javax") ? "javax" : "jakarta";
+    private static final String CDI_BEAN_MANAGER = ".persistence.bean.manager";
+    private static final String VALIDATOR_FACTORY = ".persistence.validation.factory";
 
+    private final Map properties;
     private final PersistenceProviderAdaptor persistenceProviderAdaptor;
+    private final List<PersistenceProviderIntegratorAdaptor> persistenceProviderIntegratorAdaptors;
     private final PersistenceProvider persistenceProvider;
     private final PersistenceUnitMetadata pu;
     private final ClassLoader classLoader;
@@ -92,16 +80,20 @@ public class PersistenceUnitServiceImpl implements Service<PersistenceUnitServic
     private final SetupAction javaNamespaceSetup;
 
     public PersistenceUnitServiceImpl(
+            final Map properties,
             final ClassLoader classLoader,
             final PersistenceUnitMetadata pu,
             final PersistenceProviderAdaptor persistenceProviderAdaptor,
+            final List<PersistenceProviderIntegratorAdaptor> persistenceProviderIntegratorAdaptors,
             final PersistenceProvider persistenceProvider,
             final PersistenceUnitRegistryImpl persistenceUnitRegistry,
             final ServiceName deploymentUnitServiceName,
             final ValidatorFactory validatorFactory, SetupAction javaNamespaceSetup,
             BeanManagerAfterDeploymentValidation beanManagerAfterDeploymentValidation) {
+        this.properties = properties;
         this.pu = pu;
         this.persistenceProviderAdaptor = persistenceProviderAdaptor;
+        this.persistenceProviderIntegratorAdaptors = persistenceProviderIntegratorAdaptors;
         this.persistenceProvider = persistenceProvider;
         this.classLoader = classLoader;
         this.persistenceUnitRegistry = persistenceUnitRegistry;
@@ -138,10 +130,10 @@ public class PersistenceUnitServiceImpl implements Service<PersistenceUnitServic
                                     WritableServiceBasedNamingStore.pushOwner(deploymentUnitServiceName);
                                     Object wrapperBeanManagerLifeCycle=null;
 
-                                    // as per JPA specification contract, always pass ValidatorFactory in via standard property before
+                                    // as per Jakarta Persistence specification contract, always pass ValidatorFactory in via standard property before
                                     // creating container EntityManagerFactory
                                     if (validatorFactory != null) {
-                                        properties.getValue().put(VALIDATOR_FACTORY, validatorFactory);
+                                        properties.put(EE_NAMESPACE + VALIDATOR_FACTORY, validatorFactory);
                                     }
 
                                     // handle phase 2 of 2 of bootstrapping the persistence unit
@@ -151,7 +143,7 @@ public class PersistenceUnitServiceImpl implements Service<PersistenceUnitServic
                                         phaseOnePersistenceUnitService.setSecondPhaseStarted(true);
                                         if (beanManagerInjector.getOptionalValue() != null) {
                                             wrapperBeanManagerLifeCycle = phaseOnePersistenceUnitService.getBeanManagerLifeCycle();
-                                            // update the bean manager proxy to the actual CDI bean manager
+                                            // update the bean manager proxy to the actual Jakarta Contexts and Dependency Injection bean manager
                                             proxyBeanManager = phaseOnePersistenceUnitService.getBeanManager();
                                             proxyBeanManager.setDelegate(beanManagerInjector.getOptionalValue());
                                         }
@@ -178,10 +170,10 @@ public class PersistenceUnitServiceImpl implements Service<PersistenceUnitServic
                                             wrapperBeanManagerLifeCycle = persistenceProviderAdaptor.beanManagerLifeCycle(proxyBeanManager);
                                             if (wrapperBeanManagerLifeCycle != null) {
                                               // pass the wrapper object representing the bean manager life cycle object
-                                              properties.getValue().put(CDI_BEAN_MANAGER, wrapperBeanManagerLifeCycle);
+                                              properties.put(EE_NAMESPACE + CDI_BEAN_MANAGER, wrapperBeanManagerLifeCycle);
                                             }
                                             else {
-                                              properties.getValue().put(CDI_BEAN_MANAGER, proxyBeanManager);
+                                              properties.put(EE_NAMESPACE + CDI_BEAN_MANAGER, proxyBeanManager);
                                             }
                                         }
                                         entityManagerFactory = createContainerEntityManagerFactory();
@@ -195,6 +187,7 @@ public class PersistenceUnitServiceImpl implements Service<PersistenceUnitServic
                                     context.failed(new StartException(t));
                                 } finally {
                                     Thread.currentThread().setContextClassLoader(old);
+                                    pu.setAnnotationIndex(null);    // close reference to Annotation Index
                                     pu.setTempClassLoaderFactory(null);    // release the temp classloader factory (only needed when creating the EMF)
                                     WritableServiceBasedNamingStore.popOwner();
 
@@ -247,18 +240,23 @@ public class PersistenceUnitServiceImpl implements Service<PersistenceUnitServic
                                 }
                                 try {
                                     if (entityManagerFactory != null) {
-                                        WritableServiceBasedNamingStore.pushOwner(deploymentUnitServiceName);
-                                        try {
-                                            if (entityManagerFactory.isOpen()) {
-                                                entityManagerFactory.close();
+                                        // protect against race condition reported by WFLY-11563
+                                        synchronized (this) {
+                                            if (entityManagerFactory != null) {
+                                                WritableServiceBasedNamingStore.pushOwner(deploymentUnitServiceName);
+                                                try {
+                                                    if (entityManagerFactory.isOpen()) {
+                                                        entityManagerFactory.close();
+                                                    }
+                                                } catch (Throwable t) {
+                                                    ROOT_LOGGER.failedToStopPUService(t, pu.getScopedPersistenceUnitName());
+                                                } finally {
+                                                    entityManagerFactory = null;
+                                                    pu.setTempClassLoaderFactory(null);
+                                                    WritableServiceBasedNamingStore.popOwner();
+                                                    persistenceUnitRegistry.remove(getScopedPersistenceUnitName());
+                                                }
                                             }
-                                        } catch (Throwable t) {
-                                            ROOT_LOGGER.failedToStopPUService(t, pu.getScopedPersistenceUnitName());
-                                        } finally {
-                                            entityManagerFactory = null;
-                                            pu.setTempClassLoaderFactory(null);
-                                            WritableServiceBasedNamingStore.popOwner();
-                                            persistenceUnitRegistry.remove(getScopedPersistenceUnitName());
                                         }
                                     }
                                 } finally {
@@ -268,8 +266,12 @@ public class PersistenceUnitServiceImpl implements Service<PersistenceUnitServic
                                     }
                                 }
                                 if (proxyBeanManager != null) {
-                                    proxyBeanManager.setDelegate(null);
-                                    proxyBeanManager = null;
+                                    synchronized (this) {
+                                        if (proxyBeanManager != null) {
+                                            proxyBeanManager.setDelegate(null);
+                                            proxyBeanManager = null;
+                                        }
+                                    }
                                 }
                                 context.complete();
                                 return null;
@@ -312,10 +314,6 @@ public class PersistenceUnitServiceImpl implements Service<PersistenceUnitServic
         return pu.getScopedPersistenceUnitName();
     }
 
-    public Injector<Map> getPropertiesInjector() {
-        return properties;
-    }
-
     public Injector<DataSource> getJtaDataSourceInjector() {
         return jtaDataSource;
     }
@@ -353,15 +351,12 @@ public class PersistenceUnitServiceImpl implements Service<PersistenceUnitServic
         persistenceProviderAdaptor.beforeCreateContainerEntityManagerFactory(pu);
         try {
             ROOT_LOGGER.tracef("calling createContainerEntityManagerFactory for pu=%s with integration properties=%s, application properties=%s",
-                    pu.getScopedPersistenceUnitName(), properties.getValue(), pu.getProperties());
-            return persistenceProvider.createContainerEntityManagerFactory(pu, properties.getValue());
+                    pu.getScopedPersistenceUnitName(), properties, pu.getProperties());
+            return persistenceProvider.createContainerEntityManagerFactory(pu, properties);
         } finally {
-            try {
-                persistenceProviderAdaptor.afterCreateContainerEntityManagerFactory(pu);
-            } finally {
-                pu.setAnnotationIndex(null);    // close reference to Annotation Index (only needed during call to createContainerEntityManagerFactory)
-                //This is needed if the datasource is restarted
-                //pu.setTempClassLoaderFactory(null);    // close reference to temp classloader factory (only needed during call to createEntityManagerFactory)
+            persistenceProviderAdaptor.afterCreateContainerEntityManagerFactory(pu);
+            for (PersistenceProviderIntegratorAdaptor adaptor : persistenceProviderIntegratorAdaptors) {
+                adaptor.afterCreateContainerEntityManagerFactory(pu);
             }
         }
     }
