@@ -1,3 +1,8 @@
+/*
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
+ */
+
 package org.jboss.as.test.manualmode.ejb.client.outbound.connection.security;
 
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.ALLOW_RESOURCE_SERVICE_RESTART;
@@ -31,8 +36,9 @@ import java.net.UnknownHostException;
 import java.security.Provider;
 import java.util.Properties;
 
-import javax.ejb.NoSuchEJBException;
+import jakarta.ejb.NoSuchEJBException;
 import javax.naming.Context;
+import javax.naming.InitialContext;
 import javax.naming.NamingException;
 
 import org.jboss.arquillian.container.test.api.ContainerController;
@@ -49,7 +55,6 @@ import org.jboss.as.controller.client.OperationBuilder;
 import org.jboss.as.controller.client.helpers.Operations;
 import org.jboss.as.controller.descriptions.ModelDescriptionConstants;
 import org.jboss.as.controller.operations.common.Util;
-import org.jboss.as.naming.InitialContext;
 import org.jboss.as.test.integration.security.common.SecurityTestConstants;
 import org.jboss.as.test.integration.security.common.Utils;
 import org.jboss.as.test.shared.ServerReload;
@@ -108,6 +113,7 @@ public class ElytronRemoteOutboundConnectionTestCase {
     private static final String OUTBOUND_SOCKET_BINDING = RESOURCE_PREFIX + "-outbound-socket-binding";
     private static final String DEFAULT_AUTH_CONFIG = RESOURCE_PREFIX + "-default-auth-config";
     private static final String DEFAULT_AUTH_CONTEXT = RESOURCE_PREFIX + "-default-auth-context";
+    private static final String DYNAMIC_CLIENT_AUTH_CONTEXT = RESOURCE_PREFIX + "-dynamic-client-auth-context";
     private static final String OVERRIDING_AUTH_CONFIG = RESOURCE_PREFIX + "-overriding-auth-config";
     private static final String OVERRIDING_AUTH_CONTEXT = RESOURCE_PREFIX + "-overriding-auth-context";
     private static final String REMOTE_OUTBOUND_CONNECTION = RESOURCE_PREFIX + "-remote-outbound-connection";
@@ -121,6 +127,7 @@ public class ElytronRemoteOutboundConnectionTestCase {
     private static final String DEFAULT_TRUST_STORE = RESOURCE_PREFIX + "-default-trust-store";
     private static final String DEFAULT_TRUST_MANAGER = RESOURCE_PREFIX + "-default-trust-manager";
     private static final String DEFAULT_SERVER_SSL_CONTEXT = RESOURCE_PREFIX + "-default-server-ssl-context";
+    private static final String DYNAMIC_CLIENT_SSL_CONTEXT = RESOURCE_PREFIX + "-dynamic-client-ssl-context";
     private static final String OVERRIDING_KEY_STORE = RESOURCE_PREFIX + "-overriding-key-store";
     private static final String OVERRIDING_KEY_MANAGER = RESOURCE_PREFIX + "-overriding-key-manager";
     private static final String OVERRIDING_TRUST_STORE = RESOURCE_PREFIX + "-overriding-trust-store";
@@ -241,8 +248,10 @@ public class ElytronRemoteOutboundConnectionTestCase {
         applyUpdate(clientSideMCC, getEjbConnectorOp("list-remove", CONNECTOR));
         executeBlockingReloadClientServer(clientSideMCC);
 
-        removeIfExists(clientSideMCC, getConnectionAddress(REMOTE_OUTBOUND_CONNECTION), !clientReloadRequired);
         removeIfExists(clientSideMCC, getAuthenticationContextAddress(DEFAULT_AUTH_CONTEXT), !clientReloadRequired);
+        removeIfExists(clientSideMCC, addDynamicClientSSLContext(DYNAMIC_CLIENT_SSL_CONTEXT), !clientReloadRequired);
+        removeIfExists(clientSideMCC, getServerAuthenticationContext(DYNAMIC_CLIENT_AUTH_CONTEXT), !clientReloadRequired);
+        removeIfExists(clientSideMCC, getConnectionAddress(REMOTE_OUTBOUND_CONNECTION), !clientReloadRequired);
         removeIfExists(clientSideMCC, getServerSSLContextAddress(DEFAULT_SERVER_SSL_CONTEXT), !clientReloadRequired);
         removeIfExists(clientSideMCC, getTrustManagerAddress(DEFAULT_TRUST_MANAGER), !clientReloadRequired);
         removeIfExists(clientSideMCC, getKeyStoreAddress(DEFAULT_TRUST_STORE), !clientReloadRequired);
@@ -278,7 +287,7 @@ public class ElytronRemoteOutboundConnectionTestCase {
             compositeBuilder.addStep(update);
         }
 
-        ModelNode update = Util.getWriteAttributeOperation(getDefaultHttpsListenerAddress(), SECURITY_REALM, "ApplicationRealm");
+        ModelNode update = Util.getWriteAttributeOperation(getDefaultHttpsListenerAddress(), "ssl-context", "applicationSSC");
         update.get(OPERATION_HEADERS, ALLOW_RESOURCE_SERVICE_RESTART).set(true);
         compositeBuilder.addStep(update);
 
@@ -749,6 +758,36 @@ public class ElytronRemoteOutboundConnectionTestCase {
         Assert.assertEquals(DEFAULT_USERNAME, callIntermediateWhoAmI());
     }
 
+    @Test
+    public void testAuthenticationHostConfigUsingDynamicClientSSLContextWithHttpsRemoting() {
+        //==================================
+        // Server-side server setup
+        //==================================
+        configureServerSideForInboundHttpsRemoting(serverSideMCC);
+        //==================================
+        // Client-side server setup
+        //==================================
+        applyUpdate(clientSideMCC, getAddOutboundSocketBindingOp(OUTBOUND_SOCKET_BINDING, TestSuiteEnvironment.getServerAddressNode1(),
+                54321));
+        applyUpdate(clientSideMCC, getAddAuthenticationConfigurationOp(DEFAULT_AUTH_CONFIG, HTTPS_REMOTING_PROTOCOL, PROPERTIES_REALM,
+                DEFAULT_USERNAME, DEFAULT_PASSWORD, TestSuiteEnvironment.getServerAddress(), HTTPS_REMOTING_PORT));
+        applyUpdate(clientSideMCC, getAddKeyStoreOp(DEFAULT_KEY_STORE, CLIENT_KEY_STORE_PATH, KEY_STORE_KEYPASS));
+        applyUpdate(clientSideMCC, getAddKeyManagerOp(DEFAULT_KEY_MANAGER, DEFAULT_KEY_STORE, KEY_STORE_KEYPASS));
+        applyUpdate(clientSideMCC, getAddKeyStoreOp(DEFAULT_TRUST_STORE, CLIENT_TRUST_STORE_PATH, KEY_STORE_KEYPASS));
+        applyUpdate(clientSideMCC, getAddTrustManagerOp(DEFAULT_TRUST_MANAGER, DEFAULT_TRUST_STORE));
+        applyUpdate(clientSideMCC, getAddServerSSLContextOp(DEFAULT_SERVER_SSL_CONTEXT, DEFAULT_KEY_MANAGER, DEFAULT_TRUST_MANAGER));
+        applyUpdate(clientSideMCC, getAddClientAuthenticationContextOp(DYNAMIC_CLIENT_AUTH_CONTEXT));
+        applyUpdate(clientSideMCC, getAddDynamicClientSSLContextOp(DYNAMIC_CLIENT_SSL_CONTEXT));
+        applyUpdate(clientSideMCC, getAddAuthenticationContextOp(DEFAULT_AUTH_CONTEXT, DEFAULT_AUTH_CONFIG, DYNAMIC_CLIENT_SSL_CONTEXT));
+        applyUpdate(clientSideMCC, getAddConnectionOp(REMOTE_OUTBOUND_CONNECTION, OUTBOUND_SOCKET_BINDING, ""));
+        applyUpdate(clientSideMCC, getWriteElytronDefaultAuthenticationContextOp(DEFAULT_AUTH_CONTEXT));
+        executeBlockingReloadClientServer(clientSideMCC);
+
+        deployer.deploy(EJB_SERVER_DEPLOYMENT);
+        deployer.deploy(EJB_CLIENT_DEPLOYMENT);
+        Assert.assertEquals(DEFAULT_USERNAME, callIntermediateWhoAmI());
+    }
+
     /**
      * Test verifying that if no legacy security is used in remoting outbound connection referenced from deployment and no Elytron
      * authentication context is used, the connection will fall back to using Elytron default authentication context.
@@ -1344,6 +1383,18 @@ public class ElytronRemoteOutboundConnectionTestCase {
                 .append("server-ssl-context", serverSSLContextName);
     }
 
+    private static PathAddress addDynamicClientSSLContext(String dynamicClientSSLContextName) {
+        return PathAddress.pathAddress()
+                .append(SUBSYSTEM, "elytron")
+                .append("dynamic-client-ssl-context", dynamicClientSSLContextName);
+    }
+
+    private static PathAddress getServerAuthenticationContext(String serverSSLContextName) {
+        return PathAddress.pathAddress()
+                .append(SUBSYSTEM, "elytron")
+                .append("authentication-context", serverSSLContextName);
+    }
+
     private static ModelNode getAddServerSSLContextOp(String serverSSLContextName, String keyManagerName, String trustManagerName) {
         ModelNode addServerSSLContextOp = Util.createAddOperation(getServerSSLContextAddress(serverSSLContextName));
         addServerSSLContextOp.get("trust-manager").set(trustManagerName);
@@ -1352,6 +1403,26 @@ public class ElytronRemoteOutboundConnectionTestCase {
         return addServerSSLContextOp;
     }
 
+    private static ModelNode getAddClientAuthenticationContextOp(String dsslname) {
+        ModelNode addAuthenticationContext = Util.createAddOperation(getServerAuthenticationContext(dsslname));
+
+        ModelNode matchRule = new ModelNode();
+        matchRule.get("ssl-context").set(DEFAULT_SERVER_SSL_CONTEXT);
+        matchRule.get("match-host").set(TestSuiteEnvironment.getServerAddress());
+
+        ModelNode matchRulesList = new ModelNode().addEmptyList();
+        matchRulesList.add(matchRule);
+        addAuthenticationContext.get("match-rules").set(matchRulesList);
+
+        return addAuthenticationContext;
+    }
+
+    private static ModelNode getAddDynamicClientSSLContextOp(String dynamicClientSSLContextName) {
+        ModelNode addDynamicClientSSLContext = Util.createAddOperation(addDynamicClientSSLContext(dynamicClientSSLContextName));
+        addDynamicClientSSLContext.get("authentication-context").set(DYNAMIC_CLIENT_AUTH_CONTEXT);
+        return addDynamicClientSSLContext;
+    }
+
     private static PathAddress getDefaultHttpsListenerAddress() {
         return PathAddress.pathAddress()
                 .append(SUBSYSTEM, "undertow")
