@@ -5,8 +5,10 @@
 
 package org.jboss.as.weld.logging;
 
+import java.io.File;
 import java.io.IOException;
 import java.lang.annotation.Annotation;
+import java.lang.invoke.MethodHandles;
 import java.lang.reflect.Member;
 import java.lang.reflect.Method;
 import java.lang.reflect.Type;
@@ -16,6 +18,7 @@ import java.util.Set;
 import jakarta.enterprise.inject.spi.InjectionPoint;
 
 import org.jboss.as.ee.component.ViewDescription;
+import org.jboss.as.ee.structure.DeploymentType;
 import org.jboss.as.server.deployment.DeploymentUnitProcessingException;
 import org.jboss.logging.BasicLogger;
 import org.jboss.logging.Logger;
@@ -39,12 +42,12 @@ public interface WeldLogger extends BasicLogger {
     /**
      * A logger with a category of the package name.
      */
-    WeldLogger ROOT_LOGGER = Logger.getMessageLogger(WeldLogger.class, "org.jboss.as.weld");
+    WeldLogger ROOT_LOGGER = Logger.getMessageLogger(MethodHandles.lookup(), WeldLogger.class, "org.jboss.as.weld");
 
     /**
      * A logger with the category {@code org.jboss.weld}.
      */
-    WeldLogger DEPLOYMENT_LOGGER = Logger.getMessageLogger(WeldLogger.class, "org.jboss.weld.deployer");
+    WeldLogger DEPLOYMENT_LOGGER = Logger.getMessageLogger(MethodHandles.lookup(), WeldLogger.class, "org.jboss.weld.deployer");
 
 
     @LogMessage(level= Logger.Level.ERROR)
@@ -249,4 +252,22 @@ public interface WeldLogger extends BasicLogger {
 
     @Message(id = 58, value = "Persistence unit '%s' removed.")
     IllegalStateException persistenceUnitRemoved(String scopedPuName);
+
+    @Message(id = 59, value = "Unknown deployment type %s")
+    IllegalArgumentException unknownDeploymentType(DeploymentType deploymentType);
+
+    @Message(id = 60, value = "Error handling file %s")
+    RuntimeException errorHandlingFile(File file, @Cause Throwable throwable);
+
+    @Message(id = 61, value = "Exactly one service provider is required for: %s")
+    IllegalStateException missingService(Class<?> serviceClass);
+
+    @Message(id = 62, value = "Could not determine package from corrupted class name")
+    IllegalStateException couldNotDeterminePackage();
+
+    @Message(id = 63, value = "Original %s does not have a module")
+    IllegalArgumentException originalClassDoesNotHaveAModule(Class<?> originalClass);
+
+    @Message(id = 64, value = "Incorrect setup for Weld's LiteExtensionTranslator initialization; a deployment unit has to be specified")
+    IllegalArgumentException incorrectBceTranslatorSetup();
 }
